---
title: ArchitectApi
---

## PureCloud::ArchitectApi

All URIs are relative to *https://api.mypurecloud.com*

Method | Description
------------- | ------------- | -------------
[**delete_prompts**](ArchitectApi.html#delete_prompts) | Batch-delete a list of prompts asynchronously
[**delete_prompts_prompt_id**](ArchitectApi.html#delete_prompts_prompt_id) | Delete specified user prompt
[**delete_prompts_prompt_id_resources_languagecode**](ArchitectApi.html#delete_prompts_prompt_id_resources_languagecode) | Delete specified user prompt resource
[**delete_systemprompts_prompt_id_resources_languagecode**](ArchitectApi.html#delete_systemprompts_prompt_id_resources_languagecode) | Delete a system prompt resource override.
[**get_flows**](ArchitectApi.html#get_flows) | Get a pageable list of flows, filtered by query parameters
[**get_prompts**](ArchitectApi.html#get_prompts) | Get a pageable list of user prompts
[**get_prompts_prompt_id**](ArchitectApi.html#get_prompts_prompt_id) | Get specified user prompt
[**get_prompts_prompt_id_resources**](ArchitectApi.html#get_prompts_prompt_id_resources) | Get a pageable list of user prompt resources
[**get_prompts_prompt_id_resources_languagecode**](ArchitectApi.html#get_prompts_prompt_id_resources_languagecode) | Get specified user prompt resource
[**get_systemprompts**](ArchitectApi.html#get_systemprompts) | Get System Prompts
[**get_systemprompts_prompt_id**](ArchitectApi.html#get_systemprompts_prompt_id) | Get a system prompt
[**get_systemprompts_prompt_id_resources**](ArchitectApi.html#get_systemprompts_prompt_id_resources) | Get IVR System Prompt resources.
[**get_systemprompts_prompt_id_resources_languagecode**](ArchitectApi.html#get_systemprompts_prompt_id_resources_languagecode) | Get a system prompt resource.
[**post_prompts**](ArchitectApi.html#post_prompts) | Create a new user prompt
[**post_prompts_prompt_id_resources**](ArchitectApi.html#post_prompts_prompt_id_resources) | Create a new user prompt resource
[**post_systemprompts_prompt_id_resources**](ArchitectApi.html#post_systemprompts_prompt_id_resources) | Create system prompt resource override.
[**put_prompts_prompt_id**](ArchitectApi.html#put_prompts_prompt_id) | Update specified user prompt
[**put_prompts_prompt_id_resources_languagecode**](ArchitectApi.html#put_prompts_prompt_id_resources_languagecode) | Update specified user prompt resource
[**put_systemprompts_prompt_id_resources_languagecode**](ArchitectApi.html#put_systemprompts_prompt_id_resources_languagecode) | Updates a system prompt resource override.
{: class="table table-striped"}

<a name="delete_prompts"></a>

## -[**Operation**](Operation.html) delete_prompts(id)

Batch-delete a list of prompts asynchronously

Multiple IDs can be specified, in which case all specified prompts will be deleted.

Wraps DELETE /api/v2/architect/prompts 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

id = ["id_example"] # Array<String> | List of Prompt IDs


begin
  #Batch-delete a list of prompts asynchronously
  result = api_instance.delete_prompts(id)
  p result
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->delete_prompts: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**Array&lt;String&gt;**](String.html)| List of Prompt IDs | 
{: class="table table-striped"}


### Return type

[**Operation**](Operation.html)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="delete_prompts_prompt_id"></a>

## - delete_prompts_prompt_id(prompt_id, opts)

Delete specified user prompt



Wraps DELETE /api/v2/architect/prompts/{promptId} 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

prompt_id = "prompt_id_example" # String | Prompt ID

opts = { 
  all_resources: true # BOOLEAN | Whether or not to delete all the prompt resources
}

begin
  #Delete specified user prompt
  api_instance.delete_prompts_prompt_id(prompt_id, opts)
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->delete_prompts_prompt_id: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **prompt_id** | **String**| Prompt ID | 
 **all_resources** | **BOOLEAN**| Whether or not to delete all the prompt resources | [optional] 
{: class="table table-striped"}


### Return type

nil (empty response body)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="delete_prompts_prompt_id_resources_languagecode"></a>

## - delete_prompts_prompt_id_resources_languagecode(prompt_id, language_code)

Delete specified user prompt resource



Wraps DELETE /api/v2/architect/prompts/{promptId}/resources/{languageCode} 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

prompt_id = "prompt_id_example" # String | Prompt ID

language_code = "language_code_example" # String | Language


begin
  #Delete specified user prompt resource
  api_instance.delete_prompts_prompt_id_resources_languagecode(prompt_id, language_code)
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->delete_prompts_prompt_id_resources_languagecode: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **prompt_id** | **String**| Prompt ID | 
 **language_code** | **String**| Language | 
{: class="table table-striped"}


### Return type

nil (empty response body)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="delete_systemprompts_prompt_id_resources_languagecode"></a>

## -String** delete_systemprompts_prompt_id_resources_languagecode(prompt_id, language_code)

Delete a system prompt resource override.



Wraps DELETE /api/v2/architect/systemprompts/{promptId}/resources/{languageCode} 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

prompt_id = "prompt_id_example" # String | Prompt ID

language_code = "language_code_example" # String | Language


begin
  #Delete a system prompt resource override.
  result = api_instance.delete_systemprompts_prompt_id_resources_languagecode(prompt_id, language_code)
  p result
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->delete_systemprompts_prompt_id_resources_languagecode: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **prompt_id** | **String**| Prompt ID | 
 **language_code** | **String**| Language | 
{: class="table table-striped"}


### Return type

**String**

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="get_flows"></a>

## -[**FlowEntityListing**](FlowEntityListing.html) get_flows(type, opts)

Get a pageable list of flows, filtered by query parameters

Multiple IDs can be specified, in which case all matching flows will be returned, and no other parameters will be evaluated.

Wraps GET /api/v2/flows 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

type = "type_example" # String | Type

opts = { 
  page_number: 1, # Integer | Page number
  page_size: 25, # Integer | Page size
  sort_by: "id", # String | Sort by
  sort_order: "asc", # String | Sort order
  id: ["id_example"], # Array<String> | ID
  name: "name_example", # String | Name
  description: "description_example", # String | Description
  name_or_description: "name_or_description_example", # String | Name or description
  publish_version_id: "publish_version_id_example", # String | Publish version ID
  editable_by: "editable_by_example", # String | Editable by
  locked_by: "locked_by_example", # String | Locked by
  secure: "secure_example", # String | Secure
  deleted: false, # BOOLEAN | Include deleted
  include_schemas: false # BOOLEAN | Include variable schemas
}

begin
  #Get a pageable list of flows, filtered by query parameters
  result = api_instance.get_flows(type, opts)
  p result
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->get_flows: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **type** | **String**| Type | 
 **page_number** | **Integer**| Page number | [optional] [default to 1]
 **page_size** | **Integer**| Page size | [optional] [default to 25]
 **sort_by** | **String**| Sort by | [optional] [default to id]
 **sort_order** | **String**| Sort order | [optional] [default to asc]
 **id** | [**Array&lt;String&gt;**](String.html)| ID | [optional] 
 **name** | **String**| Name | [optional] 
 **description** | **String**| Description | [optional] 
 **name_or_description** | **String**| Name or description | [optional] 
 **publish_version_id** | **String**| Publish version ID | [optional] 
 **editable_by** | **String**| Editable by | [optional] 
 **locked_by** | **String**| Locked by | [optional] 
 **secure** | **String**| Secure | [optional] 
 **deleted** | **BOOLEAN**| Include deleted | [optional] [default to false]
 **include_schemas** | **BOOLEAN**| Include variable schemas | [optional] [default to false]
{: class="table table-striped"}


### Return type

[**FlowEntityListing**](FlowEntityListing.html)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="get_prompts"></a>

## -[**PromptEntityListing**](PromptEntityListing.html) get_prompts(opts)

Get a pageable list of user prompts

The returned list is pageable, and query parameters can be used for filtering.  Multiple names can be specified, in which case all matching prompts will be returned, and no other filters will be evaluated.

Wraps GET /api/v2/architect/prompts 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

opts = { 
  page_number: 1, # Integer | Page number
  page_size: 25, # Integer | Page size
  name: "name_example", # String | Name
  description: "description_example", # String | Description
  name_or_description: "name_or_description_example" # String | Name or description
}

begin
  #Get a pageable list of user prompts
  result = api_instance.get_prompts(opts)
  p result
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->get_prompts: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **page_number** | **Integer**| Page number | [optional] [default to 1]
 **page_size** | **Integer**| Page size | [optional] [default to 25]
 **name** | **String**| Name | [optional] 
 **description** | **String**| Description | [optional] 
 **name_or_description** | **String**| Name or description | [optional] 
{: class="table table-striped"}


### Return type

[**PromptEntityListing**](PromptEntityListing.html)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="get_prompts_prompt_id"></a>

## -[**Prompt**](Prompt.html) get_prompts_prompt_id(prompt_id)

Get specified user prompt



Wraps GET /api/v2/architect/prompts/{promptId} 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

prompt_id = "prompt_id_example" # String | Prompt ID


begin
  #Get specified user prompt
  result = api_instance.get_prompts_prompt_id(prompt_id)
  p result
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->get_prompts_prompt_id: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **prompt_id** | **String**| Prompt ID | 
{: class="table table-striped"}


### Return type

[**Prompt**](Prompt.html)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="get_prompts_prompt_id_resources"></a>

## -[**PromptAssetEntityListing**](PromptAssetEntityListing.html) get_prompts_prompt_id_resources(prompt_id, opts)

Get a pageable list of user prompt resources

The returned list is pageable, and query parameters can be used for filtering.

Wraps GET /api/v2/architect/prompts/{promptId}/resources 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

prompt_id = "prompt_id_example" # String | Prompt ID

opts = { 
  page_number: 1, # Integer | Page number
  page_size: 25 # Integer | Page size
}

begin
  #Get a pageable list of user prompt resources
  result = api_instance.get_prompts_prompt_id_resources(prompt_id, opts)
  p result
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->get_prompts_prompt_id_resources: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **prompt_id** | **String**| Prompt ID | 
 **page_number** | **Integer**| Page number | [optional] [default to 1]
 **page_size** | **Integer**| Page size | [optional] [default to 25]
{: class="table table-striped"}


### Return type

[**PromptAssetEntityListing**](PromptAssetEntityListing.html)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="get_prompts_prompt_id_resources_languagecode"></a>

## -[**PromptAsset**](PromptAsset.html) get_prompts_prompt_id_resources_languagecode(prompt_id, language_code)

Get specified user prompt resource



Wraps GET /api/v2/architect/prompts/{promptId}/resources/{languageCode} 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

prompt_id = "prompt_id_example" # String | Prompt ID

language_code = "language_code_example" # String | Language


begin
  #Get specified user prompt resource
  result = api_instance.get_prompts_prompt_id_resources_languagecode(prompt_id, language_code)
  p result
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->get_prompts_prompt_id_resources_languagecode: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **prompt_id** | **String**| Prompt ID | 
 **language_code** | **String**| Language | 
{: class="table table-striped"}


### Return type

[**PromptAsset**](PromptAsset.html)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="get_systemprompts"></a>

## -[**SystemPromptEntityListing**](SystemPromptEntityListing.html) get_systemprompts(opts)

Get System Prompts



Wraps GET /api/v2/architect/systemprompts 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

opts = { 
  page_number: 1, # Integer | Page number
  page_size: 25, # Integer | Page size
  sort_by: "id", # String | Sort by
  sort_order: "asc", # String | Sort order
  name: "name_example", # String | Name
  description: "description_example", # String | Description
  name_or_description: "name_or_description_example" # String | Name or description
}

begin
  #Get System Prompts
  result = api_instance.get_systemprompts(opts)
  p result
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->get_systemprompts: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **page_number** | **Integer**| Page number | [optional] [default to 1]
 **page_size** | **Integer**| Page size | [optional] [default to 25]
 **sort_by** | **String**| Sort by | [optional] [default to id]
 **sort_order** | **String**| Sort order | [optional] [default to asc]
 **name** | **String**| Name | [optional] 
 **description** | **String**| Description | [optional] 
 **name_or_description** | **String**| Name or description | [optional] 
{: class="table table-striped"}


### Return type

[**SystemPromptEntityListing**](SystemPromptEntityListing.html)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="get_systemprompts_prompt_id"></a>

## -[**SystemPrompt**](SystemPrompt.html) get_systemprompts_prompt_id(prompt_id)

Get a system prompt



Wraps GET /api/v2/architect/systemprompts/{promptId} 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

prompt_id = "prompt_id_example" # String | promptId


begin
  #Get a system prompt
  result = api_instance.get_systemprompts_prompt_id(prompt_id)
  p result
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->get_systemprompts_prompt_id: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **prompt_id** | **String**| promptId | 
{: class="table table-striped"}


### Return type

[**SystemPrompt**](SystemPrompt.html)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="get_systemprompts_prompt_id_resources"></a>

## -[**SystemPromptAssetEntityListing**](SystemPromptAssetEntityListing.html) get_systemprompts_prompt_id_resources(prompt_id, opts)

Get IVR System Prompt resources.



Wraps GET /api/v2/architect/systemprompts/{promptId}/resources 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

prompt_id = "prompt_id_example" # String | Prompt ID

opts = { 
  page_number: 1, # Integer | Page number
  page_size: 25, # Integer | Page size
  sort_by: "id", # String | Sort by
  sort_order: "asc" # String | Sort order
}

begin
  #Get IVR System Prompt resources.
  result = api_instance.get_systemprompts_prompt_id_resources(prompt_id, opts)
  p result
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->get_systemprompts_prompt_id_resources: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **prompt_id** | **String**| Prompt ID | 
 **page_number** | **Integer**| Page number | [optional] [default to 1]
 **page_size** | **Integer**| Page size | [optional] [default to 25]
 **sort_by** | **String**| Sort by | [optional] [default to id]
 **sort_order** | **String**| Sort order | [optional] [default to asc]
{: class="table table-striped"}


### Return type

[**SystemPromptAssetEntityListing**](SystemPromptAssetEntityListing.html)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="get_systemprompts_prompt_id_resources_languagecode"></a>

## -[**SystemPromptAsset**](SystemPromptAsset.html) get_systemprompts_prompt_id_resources_languagecode(prompt_id, language_code)

Get a system prompt resource.



Wraps GET /api/v2/architect/systemprompts/{promptId}/resources/{languageCode} 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

prompt_id = "prompt_id_example" # String | Prompt ID

language_code = "language_code_example" # String | Language


begin
  #Get a system prompt resource.
  result = api_instance.get_systemprompts_prompt_id_resources_languagecode(prompt_id, language_code)
  p result
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->get_systemprompts_prompt_id_resources_languagecode: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **prompt_id** | **String**| Prompt ID | 
 **language_code** | **String**| Language | 
{: class="table table-striped"}


### Return type

[**SystemPromptAsset**](SystemPromptAsset.html)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="post_prompts"></a>

## -[**Prompt**](Prompt.html) post_prompts(opts)

Create a new user prompt



Wraps POST /api/v2/architect/prompts 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

opts = { 
  body: PureCloud::Prompt.new # Prompt | 
}

begin
  #Create a new user prompt
  result = api_instance.post_prompts(opts)
  p result
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->post_prompts: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**Prompt**](Prompt.html)|  | [optional] 
{: class="table table-striped"}


### Return type

[**Prompt**](Prompt.html)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="post_prompts_prompt_id_resources"></a>

## -[**PromptAsset**](PromptAsset.html) post_prompts_prompt_id_resources(prompt_id, opts)

Create a new user prompt resource



Wraps POST /api/v2/architect/prompts/{promptId}/resources 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

prompt_id = "prompt_id_example" # String | Prompt ID

opts = { 
  body: PureCloud::PromptAssetCreate.new # PromptAssetCreate | 
}

begin
  #Create a new user prompt resource
  result = api_instance.post_prompts_prompt_id_resources(prompt_id, opts)
  p result
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->post_prompts_prompt_id_resources: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **prompt_id** | **String**| Prompt ID | 
 **body** | [**PromptAssetCreate**](PromptAssetCreate.html)|  | [optional] 
{: class="table table-striped"}


### Return type

[**PromptAsset**](PromptAsset.html)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="post_systemprompts_prompt_id_resources"></a>

## -[**SystemPromptAsset**](SystemPromptAsset.html) post_systemprompts_prompt_id_resources(prompt_id, opts)

Create system prompt resource override.



Wraps POST /api/v2/architect/systemprompts/{promptId}/resources 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

prompt_id = "prompt_id_example" # String | Prompt ID

opts = { 
  body: PureCloud::SystemPromptAsset.new # SystemPromptAsset | 
}

begin
  #Create system prompt resource override.
  result = api_instance.post_systemprompts_prompt_id_resources(prompt_id, opts)
  p result
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->post_systemprompts_prompt_id_resources: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **prompt_id** | **String**| Prompt ID | 
 **body** | [**SystemPromptAsset**](SystemPromptAsset.html)|  | [optional] 
{: class="table table-striped"}


### Return type

[**SystemPromptAsset**](SystemPromptAsset.html)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="put_prompts_prompt_id"></a>

## -[**Prompt**](Prompt.html) put_prompts_prompt_id(prompt_id, opts)

Update specified user prompt



Wraps PUT /api/v2/architect/prompts/{promptId} 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

prompt_id = "prompt_id_example" # String | Prompt ID

opts = { 
  body: PureCloud::Prompt.new # Prompt | 
}

begin
  #Update specified user prompt
  result = api_instance.put_prompts_prompt_id(prompt_id, opts)
  p result
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->put_prompts_prompt_id: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **prompt_id** | **String**| Prompt ID | 
 **body** | [**Prompt**](Prompt.html)|  | [optional] 
{: class="table table-striped"}


### Return type

[**Prompt**](Prompt.html)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="put_prompts_prompt_id_resources_languagecode"></a>

## -[**PromptAsset**](PromptAsset.html) put_prompts_prompt_id_resources_languagecode(prompt_id, language_code, opts)

Update specified user prompt resource



Wraps PUT /api/v2/architect/prompts/{promptId}/resources/{languageCode} 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

prompt_id = "prompt_id_example" # String | Prompt ID

language_code = "language_code_example" # String | Language

opts = { 
  body: PureCloud::PromptAsset.new # PromptAsset | 
}

begin
  #Update specified user prompt resource
  result = api_instance.put_prompts_prompt_id_resources_languagecode(prompt_id, language_code, opts)
  p result
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->put_prompts_prompt_id_resources_languagecode: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **prompt_id** | **String**| Prompt ID | 
 **language_code** | **String**| Language | 
 **body** | [**PromptAsset**](PromptAsset.html)|  | [optional] 
{: class="table table-striped"}


### Return type

[**PromptAsset**](PromptAsset.html)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



<a name="put_systemprompts_prompt_id_resources_languagecode"></a>

## -[**SystemPromptAsset**](SystemPromptAsset.html) put_systemprompts_prompt_id_resources_languagecode(prompt_id, language_code, opts)

Updates a system prompt resource override.



Wraps PUT /api/v2/architect/systemprompts/{promptId}/resources/{languageCode} 


### Example
~~~ruby
# load the gem
require 'purecloud'
# setup authorization
@secret = ENV['PURECLOUD_SECRET']
@id = ENV['PURECLOUD_CLIENT_ID']
environment = "mypurecloud.com"

@authToken = PureCloud.authenticate_with_client_credentials @id, @secret, environment

PureCloud.configure do |config|
  config.access_token = @authToken
end

api_instance = PureCloud::ArchitectApi.new

prompt_id = "prompt_id_example" # String | Prompt ID

language_code = "language_code_example" # String | Language

opts = { 
  body: PureCloud::SystemPromptAsset.new # SystemPromptAsset | 
}

begin
  #Updates a system prompt resource override.
  result = api_instance.put_systemprompts_prompt_id_resources_languagecode(prompt_id, language_code, opts)
  p result
rescue PureCloud::ApiError => e
  puts "Exception when calling ArchitectApi->put_systemprompts_prompt_id_resources_languagecode: #{e}"
end
~~~

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **prompt_id** | **String**| Prompt ID | 
 **language_code** | **String**| Language | 
 **body** | [**SystemPromptAsset**](SystemPromptAsset.html)|  | [optional] 
{: class="table table-striped"}


### Return type

[**SystemPromptAsset**](SystemPromptAsset.html)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



